@@ -251,6 +251,17 @@ class FeMorphology(Element, m.FilterPrimitive):
     height: Length | Number | None = None
 
 
+@dataclass
+class FeDropShadow(Element, m.FilterPrimitive):
+    element_name = "feDropShadow"
+    dx: Optional[Any] = None
+    dy: Optional[Any] = None
+    flood_opacity: Optional[Number] = None
+    flood_color: Optional[str] = None
+    stdDeviation: Optional[Tuple[Number, Number]] = None
+    class_: Optional[list[str]] = None
+
+
 @dataclass
 class FeOffset(Element, m.FilterPrimitive):
     element_name = "feOffset"
