@@ -1,14 +1,16 @@
+from __future__ import annotations
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, ClassVar, Dict, List, Optional, Union
-
-from typing_extensions import Literal
+from typing import TYPE_CHECKING, Any, ClassVar, Optional
 
 from . import _mixins as m
 from ._path import PathData
 from ._transforms import Transform
 from ._types import Length, Number, PreserveAspectRatio, ViewBoxSpec
 
+if TYPE_CHECKING:
+    from typing_extensions import Literal
+
 
 @dataclass
 class Element:
@@ -18,7 +20,7 @@ class Element:
 
     element_name: ClassVar[str]
 
-    elements: Optional[List['Element']] = None
+    elements: Optional[list['Element']] = None
     text: Optional[str] = None
     id: Optional[str] = None
     tabindex: Optional[int] = None
@@ -42,7 +44,7 @@ class Element:
             return " ".join(cls._as_str(v) for v in val)
         return str(val)
 
-    def as_dict(self) -> Dict[str, str]:
+    def as_dict(self) -> dict[str, str]:
         result = {}
         for key, val in vars(self).items():
             if val is None:
@@ -76,14 +78,14 @@ class SVG(
     m.Graphics,
 ):
     element_name = "svg"
-    xmlns: Optional[str] = None
+    xmlns: Optional[str] = "http://www.w3.org/2000/svg"
     viewBox: Optional[ViewBoxSpec] = None
     preserveAspectRatio: Optional[PreserveAspectRatio] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
-    class_: Optional[List[str]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     opacity: Optional[Number] = None
     clip_path: Optional[str] = None
@@ -105,8 +107,8 @@ class G(
     m.Graphics,
 ):
     element_name = "g"
-    transform: Optional[List[Transform]] = None
-    class_: Optional[List[str]] = None
+    transform: Optional[list[Transform]] = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     opacity: Optional[Number] = None
     clip_path: Optional[str] = None
@@ -122,8 +124,8 @@ class Defs(
     m.GraphicsElementEvents,
 ):
     element_name = "defs"
-    transform: Optional[List[Transform]] = None
-    class_: Optional[List[str]] = None
+    transform: Optional[list[Transform]] = None
+    class_: Optional[list[str]] = None
     pointer_events: Optional[str] = None  # TODO
 
 
@@ -131,14 +133,14 @@ class Defs(
 class Desc(Element, m.GraphicsElementEvents):
     element_name = "desc"
     content: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
 
 
 @dataclass
 class Title(Element, m.GraphicsElementEvents):
     element_name = "title"
     content: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
 
 
 @dataclass
@@ -151,11 +153,11 @@ class Symbol(
     element_name = "symbol"
     viewBox: Optional[ViewBoxSpec] = None
     preserveAspectRatio: Optional[PreserveAspectRatio] = None
-    refX: Union[Length, Number, None] = None
-    refY: Union[Length, Number, None] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    class_: Optional[List[str]] = None
+    refX: Length | Number | None = None
+    refY: Length | Number | None = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     opacity: Optional[Number] = None
     clip_path: Optional[str] = None
@@ -171,14 +173,14 @@ class Image(
 ):
     element_name = "image"
     href: Optional[str] = None
-    transform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
     preserveAspectRatio: Optional[PreserveAspectRatio] = None
     image_rendering: Optional[Literal["auto", "optimizeSpeed", "optimizeQuality"]] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     vector_effect: Optional[Literal["none", "non-scaling-stroke", "non-scaling-size", "non-rotation", "fixed-position"]] = None
     visibility: Optional[Literal["visible", "hidden", "inherit"]] = None
     mask: Optional[str] = None
@@ -191,9 +193,9 @@ class Image(
 class Switch(Element, m.Color, m.GraphicsElementEvents):
     element_name = "switch"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
+    transform: Optional[list[Transform]] = None
     opacity: Optional[Number] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     pointer_events: Optional[str] = None  # TODO
 
 
@@ -201,7 +203,7 @@ class Switch(Element, m.Color, m.GraphicsElementEvents):
 class Style(Element, m.GraphicsElementEvents):
     element_name = "style"
     type: Optional[str] = None
-    media: Optional[List[str]] = None
+    media: Optional[list[str]] = None
     title: Optional[str] = None
 
 
@@ -210,7 +212,7 @@ class _FigureElement(m.Color, m.GraphicsElementEvents, m.Graphics, m.FillStroke)
     pathLength: Optional[float] = None
     paint_order: Optional[Literal["normal", "fill", "stroke", "markers"]] = None
     shape_rendering: Optional[Literal["auto", "optimizeSpeed", "crispEdges", "geometricPrecision", "inherit"]] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     vector_effect: Optional[Literal["none", "non-scaling-stroke", "non-scaling-size", "non-rotation", "fixed-position"]] = None
     visibility: Optional[Literal["visible", "hidden", "inherit"]] = None
     mask: Optional[str] = None
@@ -222,8 +224,8 @@ class _FigureElement(m.Color, m.GraphicsElementEvents, m.Graphics, m.FillStroke)
 class Path(Element, _FigureElement):
     element_name = "path"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    d: Optional[List[PathData]] = None
+    transform: Optional[list[Transform]] = None
+    d: Optional[list[PathData]] = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -239,13 +241,13 @@ class Path(Element, _FigureElement):
 class Rect(Element, _FigureElement):
     element_name = "rect"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
-    rx: Union[Length, Number, None] = None
-    ry: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
+    rx: Length | Number | None = None
+    ry: Length | Number | None = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -259,10 +261,10 @@ class Rect(Element, _FigureElement):
 class Circle(Element, _FigureElement):
     element_name = "circle"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    cx: Union[Length, Number, None] = None
-    cy: Union[Length, Number, None] = None
-    r: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    cx: Length | Number | None = None
+    cy: Length | Number | None = None
+    r: Length | Number | None = None
     marker_mid: Optional[str] = None
     fill_opacity: Optional[Number] = None
     fill: Optional[str] = None
@@ -272,11 +274,11 @@ class Circle(Element, _FigureElement):
 class Ellipse(Element, _FigureElement):
     element_name = "ellipse"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    cx: Union[Length, Number, None] = None
-    cy: Union[Length, Number, None] = None
-    rx: Union[Length, Number, None] = None
-    ry: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    cx: Length | Number | None = None
+    cy: Length | Number | None = None
+    rx: Length | Number | None = None
+    ry: Length | Number | None = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -288,11 +290,11 @@ class Ellipse(Element, _FigureElement):
 class Line(Element, _FigureElement):
     element_name = "line"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    x1: Union[Length, Number, None] = None
-    y1: Union[Length, Number, None] = None
-    x2: Union[Length, Number, None] = None
-    y2: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x1: Length | Number | None = None
+    y1: Length | Number | None = None
+    x2: Length | Number | None = None
+    y2: Length | Number | None = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -303,8 +305,8 @@ class Line(Element, _FigureElement):
 class Polyline(Element, _FigureElement):
     element_name = "polyline"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    points: Optional[List[Number]] = None
+    transform: Optional[list[Transform]] = None
+    points: Optional[list[Number]] = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -320,8 +322,8 @@ class Polyline(Element, _FigureElement):
 class Polygon(Element, _FigureElement):
     element_name = "polygon"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    points: Optional[List[Number]] = None
+    transform: Optional[list[Transform]] = None
+    points: Optional[list[Number]] = None
     marker_start: Optional[str] = None
     marker_mid: Optional[str] = None
     marker_end: Optional[str] = None
@@ -342,7 +344,7 @@ class _TextElement(
     m.FillStroke,
 ):
     paint_order: Optional[Literal["normal", "fill", "stroke", "markers"]] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     vector_effect: Optional[Literal["none", "non-scaling-stroke", "non-scaling-size", "non-rotation", "fixed-position"]] = None
     visibility: Optional[Literal["visible", "hidden", "inherit"]] = None
     fill_opacity: Optional[Number] = None
@@ -356,12 +358,12 @@ class Text(Element, _TextElement):
     """
     element_name = "text"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    dx: Union[Length, Number, None] = None
-    dy: Union[Length, Number, None] = None
-    textLength: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    dx: Length | Number | None = None
+    dy: Length | Number | None = None
+    textLength: Length | Number | None = None
     lengthAdjust: Optional[Literal["spacing", "spacingAndGlyphs"]] = None
     writing_mode: Optional[Literal["horizontal-tb", "vertical-rl", "vertical-lr"]] = None
     text_rendering: Optional[Literal["auto", "optimizeSpeed", "optimizeLegibility", "geometricPrecision"]] = None
@@ -379,11 +381,11 @@ class Text(Element, _TextElement):
 class TSpan(Element, _TextElement):
     element_name = "tspan"
     externalResourcesRequired: Optional[bool] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    dx: Union[Length, Number, None] = None
-    dy: Union[Length, Number, None] = None
-    textLength: Union[Length, Number, None] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    dx: Length | Number | None = None
+    dy: Length | Number | None = None
+    textLength: Length | Number | None = None
     lengthAdjust: Optional[Literal["spacing", "spacingAndGlyphs"]] = None
     writing_mode: Optional[Literal["horizontal-tb", "vertical-rl", "vertical-lr"]] = None
     alignment_baseline: Optional[Literal[
@@ -405,7 +407,7 @@ class TextPath(Element, _TextElement):
     element_name = "textPath"
     externalResourcesRequired: Optional[bool] = None
     startOffset: Optional[str] = None
-    textLength: Union[Length, Number, None] = None
+    textLength: Length | Number | None = None
     lengthAdjust: Optional[Literal["spacing", "spacingAndGlyphs"]] = None
     method: Optional[Literal["align", "stretch"]] = None
     spacing: Optional[Literal["auto", "exact"]] = None
@@ -433,15 +435,15 @@ class Marker(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
     externalResourcesRequired: Optional[bool] = None
     viewBox: Optional[ViewBoxSpec] = None
     preserveAspectRatio: Optional[PreserveAspectRatio] = None
-    refX: Union[Length, Number, None] = None
-    refY: Union[Length, Number, None] = None
+    refX: Length | Number | None = None
+    refY: Length | Number | None = None
     markerUnits: Optional[Literal["strokeWidth", "userSpaceOnUse", "userSpace"]] = None
-    markerWidth: Union[Length, Number, None] = None
-    markerHeight: Union[Length, Number, None] = None
+    markerWidth: Length | Number | None = None
+    markerHeight: Length | Number | None = None
     orient: Optional[str] = None
     opacity: Optional[Number] = None
     clip_path: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     overflow: Optional[Literal["visible", "hidden", "scroll", "auto", "inherit"]] = None
 
@@ -456,39 +458,39 @@ class ColorProfile(Element):
 class _Gradient:
     externalResourcesRequired: Optional[bool] = None
     gradientUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
-    gradientTransform: Optional[List[Transform]] = None
+    gradientTransform: Optional[list[Transform]] = None
     spreadMethod: Optional[Literal["pad", "reflect", "repeat"]] = None
     href: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
 
 
 @dataclass
 class LinearGradient(Element, _Gradient, m.Color, m.GraphicsElementEvents):
     element_name = "linearGradient"
-    x1: Union[Length, Number, None] = None
-    y1: Union[Length, Number, None] = None
-    x2: Union[Length, Number, None] = None
-    y2: Union[Length, Number, None] = None
+    x1: Length | Number | None = None
+    y1: Length | Number | None = None
+    x2: Length | Number | None = None
+    y2: Length | Number | None = None
 
 
 @dataclass
 class RadialGradient(Element, _Gradient, m.Color, m.GraphicsElementEvents):
     element_name = "radialGradient"
-    cx: Union[Length, Number, None] = None
-    cy: Union[Length, Number, None] = None
-    r: Union[Length, Number, None] = None
-    fr: Union[Length, Number, None] = None
-    fx: Union[Length, Number, None] = None
-    fy: Union[Length, Number, None] = None
+    cx: Length | Number | None = None
+    cy: Length | Number | None = None
+    r: Length | Number | None = None
+    fr: Length | Number | None = None
+    fx: Length | Number | None = None
+    fy: Length | Number | None = None
 
 
 @dataclass
 class Stop(Element, m.GraphicsElementEvents):
     element_name = "stop"
-    offset: Union[Length, Number, None] = None
+    offset: Length | Number | None = None
     stop_opacity: Optional[Number] = None
     stop_color: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
 
 
 @dataclass
@@ -498,14 +500,14 @@ class Pattern(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
     viewBox: Optional[ViewBoxSpec] = None
     preserveAspectRatio: Optional[PreserveAspectRatio] = None
     patternUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
-    patternTransform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
+    patternTransform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
     patternContentUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
     href: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     clip_path: Optional[str] = None
     overflow: Optional[Literal["visible", "hidden", "scroll", "auto", "inherit"]] = None
@@ -515,9 +517,9 @@ class Pattern(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
 class ClipPath(Element, m.Color, m.Graphics):
     element_name = "clipPath"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
+    transform: Optional[list[Transform]] = None
     clipPathUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     clip_path: Optional[str] = None
 
@@ -526,14 +528,14 @@ class ClipPath(Element, m.Color, m.Graphics):
 class Mask(Element, m.Color, m.Graphics):
     element_name = "mask"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
+    transform: Optional[list[Transform]] = None
     maskUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
     maskContentUnits: Optional[Literal["userSpaceOnUse", "objectBoundingBox"]] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     mask: Optional[str] = None
     clip_path: Optional[str] = None
 
@@ -542,10 +544,10 @@ class Mask(Element, m.Color, m.Graphics):
 class A(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
     element_name = "a"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
+    transform: Optional[list[Transform]] = None
     target: Optional[Literal["_self", "_parent", "_top", "_blank"]] = None
     href: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     visibility: Optional[Literal["visible", "hidden", "inherit"]] = None
     mask: Optional[str] = None
     opacity: Optional[Number] = None
@@ -629,13 +631,13 @@ class Metadata(Element, m.GraphicsElementEvents):
 class ForeignObject(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
     element_name = "foreignObject"
     externalResourcesRequired: Optional[bool] = None
-    transform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
     content: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     vector_effect: Optional[Literal["none", "non-scaling-stroke", "non-scaling-size", "non-rotation", "fixed-position"]] = None
     visibility: Optional[Literal["visible", "hidden", "inherit"]] = None
     opacity: Optional[Number] = None
@@ -646,13 +648,13 @@ class ForeignObject(Element, m.Color, m.GraphicsElementEvents, m.Graphics):
 class Use(Element, m.GraphicsElementEvents, m.Color, m.Graphics, m.FillStroke):
     element_name = "use"
     href: Optional[str] = None
-    class_: Optional[List[str]] = None
+    class_: Optional[list[str]] = None
     style: Optional[str] = None
-    transform: Optional[List[Transform]] = None
-    x: Union[Length, Number, None] = None
-    y: Union[Length, Number, None] = None
-    width: Union[Length, Number, None] = None
-    height: Union[Length, Number, None] = None
+    transform: Optional[list[Transform]] = None
+    x: Length | Number | None = None
+    y: Length | Number | None = None
+    width: Length | Number | None = None
+    height: Length | Number | None = None
     vector_effect: Optional[Literal["none", "non-scaling-stroke", "non-scaling-size", "non-rotation", "fixed-position"]] = None
     opacity: Optional[Number] = None
     clip_path: Optional[str] = None
